@@ -100,6 +100,9 @@ class JManFb:
     def c_sync_productes(self):
         return self.select(sql=fb_consultes.sync_productes)
 
+    def c_sync_condicions_pagament(self):
+        return self.select(sql=fb_consultes.sync_condicions_pagament)
+
     def c_sync_transportistes(self):
         return self.select(sql=fb_consultes.sync_transportistes)
 
